@@ -35,9 +35,18 @@ class SensorTemperatureMessage(Message):
         self.needs_no_rtr(rtr)
         self.needs_data(data, 6)
         self.set_attributes(priority, address, rtr)
-        self.cur = (((data[0] << 8) | data[1]) / 32) * 0.0625
-        self.min = (((data[2] << 8) | data[3]) / 32) * 0.0625
-        self.max = (((data[4] << 8) | data[5]) / 32) * 0.0625
+        if ((data[0] << 8) | data[1]) >> 15:
+            self.cur = -127 + (((data[0] << 8) | data[1]) / 32 * 0.0625)
+        else:
+            self.cur = (((data[0] << 8) | data[1]) / 32) * 0.0625
+        if ((data[2] << 8) | data[3]) >> 15:
+            self.min = -127 + (((data[2] << 8) | data[3]) / 32 * 0.0625)
+        else:
+            self.min = (((data[2] << 8) | data[3]) / 32) * 0.0625
+        if ((data[4] << 8) | data[5]) >> 15:
+            self.max = -127 + (((data[4] << 8) | data[5]) / 32 * 0.0625)
+        else:
+            self.max = (((data[4] << 8) | data[5]) / 32) * 0.0625
 
     def to_json(self):
         """
